"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);

// Default empty arrays as stable references
const DEFAULT_LANGUAGES = [];
const DEFAULT_THEMES = [];
function ShikiProvider({
  children,
  initialLanguages = DEFAULT_LANGUAGES,
  initialThemes = DEFAULT_THEMES
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const initializeHighlighter = async () => {
      try {
        const instance = await (0, _core.createHighlighterCore)({
          engine: (0, _engineJavascript.createJavaScriptRegexEngine)(),
          langs: initialLanguages,
          themes: initialThemes
        });
        setHighlighter(instance);
        setIsReady(true);
      } catch (err) {
        setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
      }
    };
    initializeHighlighter();
  }, [initialLanguages, initialThemes]);
  const registerLanguage = (0, _react.useCallback)(async lang => {
    if (!highlighter) return;
    await highlighter.loadLanguage(lang);
  }, [highlighter]);
  const registerTheme = (0, _react.useCallback)(async theme => {
    if (!highlighter) return;
    await highlighter.loadTheme(theme);
  }, [highlighter]);
  const getLoadedLanguages = (0, _react.useCallback)(() => {
    return highlighter ? highlighter.getLoadedLanguages() : [];
  }, [highlighter]);
  const getLoadedThemes = (0, _react.useCallback)(() => {
    return highlighter ? highlighter.getLoadedThemes() : [];
  }, [highlighter]);
  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error,
    registerLanguage,
    registerTheme,
    getLoadedLanguages,
    getLoadedThemes
  }), [highlighter, isReady, error, registerLanguage, registerTheme, getLoadedLanguages, getLoadedThemes]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map