"use strict";

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { createContext, useCallback, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const ShikiContext = /*#__PURE__*/createContext(null);

// Default empty arrays as stable references
const DEFAULT_LANGUAGES = [];
const DEFAULT_THEMES = [];
export function ShikiProvider({
  children,
  initialLanguages = DEFAULT_LANGUAGES,
  initialThemes = DEFAULT_THEMES
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initializeHighlighter = async () => {
      try {
        const instance = await createHighlighterCore({
          engine: createJavaScriptRegexEngine(),
          langs: initialLanguages,
          themes: initialThemes
        });
        setHighlighter(instance);
        setIsReady(true);
      } catch (err) {
        setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
      }
    };
    initializeHighlighter();
  }, [initialLanguages, initialThemes]);
  const registerLanguage = useCallback(async lang => {
    if (!highlighter) return;
    await highlighter.loadLanguage(lang);
  }, [highlighter]);
  const registerTheme = useCallback(async theme => {
    if (!highlighter) return;
    await highlighter.loadTheme(theme);
  }, [highlighter]);
  const getLoadedLanguages = useCallback(() => {
    return highlighter ? highlighter.getLoadedLanguages() : [];
  }, [highlighter]);
  const getLoadedThemes = useCallback(() => {
    return highlighter ? highlighter.getLoadedThemes() : [];
  }, [highlighter]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error,
    registerLanguage,
    registerTheme,
    getLoadedLanguages,
    getLoadedThemes
  }), [highlighter, isReady, error, registerLanguage, registerTheme, getLoadedLanguages, getLoadedThemes]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map